@@ -1,7 +1,7 @@
 """
 TODO: write doc
 """
-__title__ = 'Events'
+__title__ = "Events"
 
 from .badweather import BadWeatherEvent
 from .exposurestatuschanged import ExposureStatusChangedEvent
@@ -9,21 +9,17 @@ from .event import Event
 from .filterchanged import FilterChangedEvent
 from .focusfound import FocusFoundEvent
 from .goodweather import GoodWeatherEvent
-from .initialized import InitializedEvent
 from .log import LogEvent
 from .moduleclosed import ModuleClosedEvent
 from .moduleopened import ModuleOpenedEvent
 from .motionstatuschanged import MotionStatusChangedEvent
+from .move import MoveEvent, MoveRaDecEvent, MoveAltAzEvent
 from .newimage import NewImageEvent
+from .newspectrum import NewSpectrumEvent
 from .roofclosing import RoofClosingEvent
 from .roofopened import RoofOpenedEvent
 from .taskstarted import TaskStartedEvent
+from .taskfailed import TaskFailedEvent
 from .taskfinished import TaskFinishedEvent
-from .telescopemoving import TelescopeMovingEvent
 from .testevent import TestEvent
-
-
-__all__ = ['Event', 'BadWeatherEvent', 'ExposureStatusChangedEvent', 'FilterChangedEvent', 'FocusFoundEvent',
-           'GoodWeatherEvent', 'InitializedEvent', 'LogEvent', 'ModuleClosedEvent', 'ModuleOpenedEvent',
-           'MotionStatusChangedEvent', 'NewImageEvent', 'RoofClosingEvent', 'RoofOpenedEvent', 'TaskStartedEvent',
-           'TaskFinishedEvent', 'TelescopeMovingEvent', 'TestEvent']
+from .offsets import OffsetsEvent, OffsetsRaDecEvent, OffsetsAltAzEvent
